telephonyserverplugins/ctsydispatchlayer/test/ltsyskeleton_using_dispatcher/ltsyskeleton/src/cltsycallcontrolhandler.cpp
branchRCL_3
changeset 14 7ef16719d8cb
parent 0 3553901f7fa8
child 24 6638e7f4bd8f
--- a/telephonyserverplugins/ctsydispatchlayer/test/ltsyskeleton_using_dispatcher/ltsyskeleton/src/cltsycallcontrolhandler.cpp	Fri Feb 19 23:59:33 2010 +0200
+++ b/telephonyserverplugins/ctsydispatchlayer/test/ltsyskeleton_using_dispatcher/ltsyskeleton/src/cltsycallcontrolhandler.cpp	Fri Mar 12 15:49:38 2010 +0200
@@ -385,12 +385,12 @@
 	} // CLtsyCallControlHandler::HandleDialReqL
 
 
-TInt CLtsyCallControlHandler::HandleTransferReqL(TInt aHeldCallId, TInt aSecondCallId)
+TInt CLtsyCallControlHandler::HandleTransferReqL(TInt aCallId, TInt aSecondCallId)
 /**
  * This request is completed by invoking
  * CCtsyDispatcherCallback::CallbackCallControlTransferComp()
  *
  * @param aHeldCallId Call ID of the held call to transfer.
  *
  * @param aSecondCallId Call ID of the other to transfer the held call to.
  *
@@ -406,7 +406,7 @@
 
 	// REMOVE this line when implementing for real LTSY
 	MTEST_ISSUE_MOCKLTSYENGINE_REQ(ret, KDispatchCallControlFuncUnitId, MLtsyDispatchCallControlTransfer::KLtsyDispatchCallControlTransferApiId,
-			aHeldCallId, aSecondCallId);
+			aCallId, aSecondCallId);
 
 	return TSYLOGSETEXITERR(ret);
 	} // CLtsyCallControlHandler::HandleTransferReqL
@@ -467,14 +467,14 @@
 	} // CLtsyCallControlHandler::HandleGetIdentityServiceStatusReqL
 
 
-TInt CLtsyCallControlHandler::HandleSwapReqL(TInt aHeldCallId, TInt aConnectedCallId)
+TInt CLtsyCallControlHandler::HandleSwapReqL(TInt aCallId, TInt aSecondCallId)
 /**
  * This request is completed by invoking
  * CCtsyDispatcherCallback::CallbackCallControlSwapComp()
  *
  * @param aHeldCallId The Call ID of the held call to swap.
  *
- * @param aConnectedCallId The Call ID of the connected call to swap.
+ * @param aSecondCallId The Call ID of the second call to swap.
  *
  * @return KErrNone on success, KErrNotSupported if this request is not supported,
  * or another error code to indicate the failure otherwise.
@@ -488,11 +488,34 @@
 
 	// REMOVE this line when implementing for real LTSY
 	MTEST_ISSUE_MOCKLTSYENGINE_REQ(ret, KDispatchCallControlFuncUnitId, MLtsyDispatchCallControlSwap::KLtsyDispatchCallControlSwapApiId,
-			aHeldCallId, aConnectedCallId);
+			aCallId, aSecondCallId);
 
 	return TSYLOGSETEXITERR(ret);
 	} // CLtsyCallControlHandler::HandleSwapReqL
 
+TInt CLtsyCallControlHandler::HandleSwapReqL(TInt aCallId)
+/**
+ * This request is completed by invoking
+ * CCtsyDispatcherCallback::CallbackCallControlSwapComp()
+ *
+ * @param aCallId The Call ID of the call to swap.
+ *
+ * @return KErrNone on success, KErrNotSupported if this request is not supported,
+ * or another error code to indicate the failure otherwise.
+ */
+	{
+	TSYLOGENTRYEXIT;
+
+	TInt ret = KErrNotSupported;
+
+	// Add implementation here.......
+
+	// REMOVE this line when implementing for real LTSY
+	MTEST_ISSUE_MOCKLTSYENGINE_REQ(ret, KDispatchCallControlFuncUnitId, MLtsyDispatchCallControlSwap::KLtsyDispatchCallControlSingleSwapApiId,
+			aCallId);
+
+	return TSYLOGSETEXITERR(ret);
+	} // CLtsyCallControlHandler::HandleSwapReqL
 
 TInt CLtsyCallControlHandler::HandleLoanDataPortSyncL(TInt aCallId, RCall::TCommPort& aCommPort)
 /**
@@ -385,12 +385,12 @@
  * CCtsyDispatcherCallback::CallbackCallControlTransferComp()
  *
- * @param aHeldCallId Call ID of the held call to transfer.
+ * @param aCallId Call ID of the held call to transfer.
  *
  * @param aSecondCallId Call ID of the other to transfer the held call to.
@@ -467,14 +467,14 @@
  * CCtsyDispatcherCallback::CallbackCallControlSwapComp()
  *
- * @param aHeldCallId The Call ID of the held call to swap.
+ * @param aCallId The Call ID of the call to swap.
  *